==> benchmark-api-1.9.3-sources.jar: org/opendaylight/yang/gen/v1/rpcbench/payload/rev150702/GlobalRpcBenchInputBuilder.java <==
package org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.payload.Payload;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link GlobalRpcBenchInputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     GlobalRpcBenchInputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new GlobalRpcBenchInputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of GlobalRpcBenchInputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see GlobalRpcBenchInputBuilder
 * @see Builder
 *
 */
public class GlobalRpcBenchInputBuilder implements Builder<GlobalRpcBenchInput> {

    private List<Payload> _payload;


    Map<Class<? extends Augmentation<GlobalRpcBenchInput>>, Augmentation<GlobalRpcBenchInput>> augmentation = Collections.emptyMap();

    public GlobalRpcBenchInputBuilder() {
    }
    public GlobalRpcBenchInputBuilder(org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload arg) {
        this._payload = arg.getPayload();
    }

    public GlobalRpcBenchInputBuilder(GlobalRpcBenchInput base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<GlobalRpcBenchInput>>, Augmentation<GlobalRpcBenchInput>> aug =((AugmentationHolder<GlobalRpcBenchInput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._payload = base.getPayload();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload) {
            this._payload = ((org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload)arg).getPayload();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload]");
    }

    public List<Payload> getPayload() {
        return _payload;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<GlobalRpcBenchInput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    public GlobalRpcBenchInputBuilder setPayload(final List<Payload> values) {
        this._payload = values;
        return this;
    }
    
    
    public GlobalRpcBenchInputBuilder addAugmentation(Class<? extends Augmentation<GlobalRpcBenchInput>> augmentationType, Augmentation<GlobalRpcBenchInput> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public GlobalRpcBenchInputBuilder removeAugmentation(Class<? extends Augmentation<GlobalRpcBenchInput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public GlobalRpcBenchInput build() {
        return new GlobalRpcBenchInputImpl(this);
    }

    private static final class GlobalRpcBenchInputImpl
        extends AbstractAugmentable<GlobalRpcBenchInput>
        implements GlobalRpcBenchInput {
    
        private final List<Payload> _payload;
    
        GlobalRpcBenchInputImpl(GlobalRpcBenchInputBuilder base) {
            super(base.augmentation);
            this._payload = base.getPayload();
        }
    
        @Override
        public List<Payload> getPayload() {
            return _payload;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_payload);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!GlobalRpcBenchInput.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            GlobalRpcBenchInput other = (GlobalRpcBenchInput)obj;
            if (!Objects.equals(_payload, other.getPayload())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                GlobalRpcBenchInputImpl otherImpl = (GlobalRpcBenchInputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<GlobalRpcBenchInput>>, Augmentation<GlobalRpcBenchInput>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("GlobalRpcBenchInput");
            CodeHelpers.appendValue(helper, "_payload", _payload);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> benchmark-api-2.0.2-sources.jar: org/opendaylight/yang/gen/v1/rpcbench/payload/rev150702/GlobalRpcBenchInputBuilder.java <==
package org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.payload.Payload;
import org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.payload.PayloadKey;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link GlobalRpcBenchInputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     GlobalRpcBenchInputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new GlobalRpcBenchInputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of GlobalRpcBenchInputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see GlobalRpcBenchInputBuilder
 * @see Builder
 *
 */
public class GlobalRpcBenchInputBuilder implements Builder<GlobalRpcBenchInput> {

    private Map<PayloadKey, Payload> _payload;


    Map<Class<? extends Augmentation<GlobalRpcBenchInput>>, Augmentation<GlobalRpcBenchInput>> augmentation = Collections.emptyMap();

    public GlobalRpcBenchInputBuilder() {
    }
    public GlobalRpcBenchInputBuilder(org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload arg) {
        this._payload = arg.getPayload();
    }

    public GlobalRpcBenchInputBuilder(GlobalRpcBenchInput base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<GlobalRpcBenchInput>>, Augmentation<GlobalRpcBenchInput>> aug =((AugmentationHolder<GlobalRpcBenchInput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._payload = base.getPayload();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload) {
            this._payload = ((org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload)arg).getPayload();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.rpcbench.payload.rev150702.Payload]");
    }

    public Map<PayloadKey, Payload> getPayload() {
        return _payload;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<GlobalRpcBenchInput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    public GlobalRpcBenchInputBuilder setPayload(final Map<PayloadKey, Payload> values) {
        this._payload = values;
        return this;
    }
    
    /**
      * Utility migration setter.
      *
      * <b>IMPORTANT NOTE</b>: This method does not completely match previous mechanics, as the list is processed as
      *                        during this method's execution. Any future modifications of the list are <b>NOT</b>
      *                        reflected in this builder nor its products.
      *
      * @param values Legacy List of values
      * @return this builder
      * @throws IllegalArgumentException if the list contains entries with the same key
      * @throws NullPointerException if the list contains a null entry
      * @deprecated Use {#link #setPayload(Map)} instead.
      */
    @Deprecated(forRemoval = true)
    public GlobalRpcBenchInputBuilder setPayload(final List<Payload> values) {
        return setPayload(CodeHelpers.compatMap(values));
    }
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public GlobalRpcBenchInputBuilder addAugmentation(Augmentation<GlobalRpcBenchInput> augmentation) {
        return doAddAugmentation(augmentation.implementedInterface(), augmentation);
    }
    
    /**
      * Add or remove an augmentation to this builder's product.
      *
      * @param augmentationType augmentation type to be added or removed
      * @param augmentationValue augmentation value, null if the augmentation type should be removed
      * @return this builder
      * @deprecated Use either {@link #addAugmentation(Augmentation)} or {@link #removeAugmentation(Class)} instead.
      */
    @Deprecated(forRemoval = true)
    public GlobalRpcBenchInputBuilder addAugmentation(Class<? extends Augmentation<GlobalRpcBenchInput>> augmentationType, Augmentation<GlobalRpcBenchInput> augmentationValue) {
        return augmentationValue == null ? removeAugmentation(augmentationType) : doAddAugmentation(augmentationType, augmentationValue);
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public GlobalRpcBenchInputBuilder removeAugmentation(Class<? extends Augmentation<GlobalRpcBenchInput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }
    
    private GlobalRpcBenchInputBuilder doAddAugmentation(Class<? extends Augmentation<GlobalRpcBenchInput>> augmentationType, Augmentation<GlobalRpcBenchInput> augmentationValue) {
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }

    @Override
    public GlobalRpcBenchInput build() {
        return new GlobalRpcBenchInputImpl(this);
    }

    private static final class GlobalRpcBenchInputImpl
        extends AbstractAugmentable<GlobalRpcBenchInput>
        implements GlobalRpcBenchInput {
    
        private final Map<PayloadKey, Payload> _payload;
    
        GlobalRpcBenchInputImpl(GlobalRpcBenchInputBuilder base) {
            super(base.augmentation);
            this._payload = CodeHelpers.emptyToNull(base.getPayload());
        }
    
        @Override
        public Map<PayloadKey, Payload> getPayload() {
            return _payload;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_payload);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!GlobalRpcBenchInput.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            GlobalRpcBenchInput other = (GlobalRpcBenchInput)obj;
            if (!Objects.equals(_payload, other.getPayload())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                GlobalRpcBenchInputImpl otherImpl = (GlobalRpcBenchInputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<GlobalRpcBenchInput>>, Augmentation<GlobalRpcBenchInput>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("GlobalRpcBenchInput");
            CodeHelpers.appendValue(helper, "_payload", _payload);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
